==> kauth-5.73.0.tgz: include/KF5/KAuth/kauthcore_export.h <==

#ifndef KAUTHCORE_EXPORT_H
#define KAUTHCORE_EXPORT_H

#ifdef KAUTHCORE_STATIC_DEFINE
#  define KAUTHCORE_EXPORT
#  define KAUTHCORE_NO_EXPORT
#else
#  ifndef KAUTHCORE_EXPORT
#    ifdef KF5AuthCore_EXPORTS
        /* We are building this library */
#      define KAUTHCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KAUTHCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KAUTHCORE_NO_EXPORT
#    define KAUTHCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KAUTHCORE_DECL_DEPRECATED
#  define KAUTHCORE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KAUTHCORE_DECL_DEPRECATED_EXPORT
#  define KAUTHCORE_DECL_DEPRECATED_EXPORT KAUTHCORE_EXPORT KAUTHCORE_DECL_DEPRECATED
#endif

#ifndef KAUTHCORE_DECL_DEPRECATED_NO_EXPORT
#  define KAUTHCORE_DECL_DEPRECATED_NO_EXPORT KAUTHCORE_NO_EXPORT KAUTHCORE_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KAUTHCORE_NO_DEPRECATED
#    define KAUTHCORE_NO_DEPRECATED
#  endif
#endif

#define KAUTHCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KAUTHCORE_NO_DEPRECATED) && !defined(KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KAUTHCORE_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KAUTHCORE_NO_DEPRECATED_WARNINGS) && !defined(KAUTHCORE_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KAUTHCORE_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KAUTHCORE_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KAUTHCORE_NO_DEPRECATED)
#  undef KAUTHCORE_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_NO_EXPORT
#elif defined(KAUTHCORE_NO_DEPRECATED_WARNINGS)
#  define KAUTHCORE_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_NO_EXPORT
#else
#  define KAUTHCORE_DEPRECATED KAUTHCORE_DECL_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_DECL_DEPRECATED_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KAUTHCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KAUTHCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KAUTHCORE_NO_DEPRECATED
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54900
#endif
#ifdef KAUTHCORE_NO_DEPRECATED_WARNINGS
#  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KAUTHCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x54900
#  endif
#endif

#ifndef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KAUTHCORE_DEPRECATED
#  define KAUTHCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KAUTHCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KAUTHCORE_DEPRECATED_WARNINGS_SINCE >= 0x54700
#  define KAUTHCORE_DEPRECATED_VERSION_5_71(text) KAUTHCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KAUTHCORE_DEPRECATED_VERSION_5_71(text)
#endif
#define KAUTHCORE_DEPRECATED_VERSION_5(minor, text)      KAUTHCORE_DEPRECATED_VERSION_5_##minor(text)
#define KAUTHCORE_DEPRECATED_VERSION(major, minor, text) KAUTHCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KAUTHCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KAUTHCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KAUTHCORE_EXPORT_H */

==> kauth-5.85.0.tgz: include/KF5/KAuth/kauthcore_export.h <==

#ifndef KAUTHCORE_EXPORT_H
#define KAUTHCORE_EXPORT_H

#ifdef KAUTHCORE_STATIC_DEFINE
#  define KAUTHCORE_EXPORT
#  define KAUTHCORE_NO_EXPORT
#else
#  ifndef KAUTHCORE_EXPORT
#    ifdef KF5AuthCore_EXPORTS
        /* We are building this library */
#      define KAUTHCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KAUTHCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KAUTHCORE_NO_EXPORT
#    define KAUTHCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KAUTHCORE_DECL_DEPRECATED
#  define KAUTHCORE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KAUTHCORE_DECL_DEPRECATED_EXPORT
#  define KAUTHCORE_DECL_DEPRECATED_EXPORT KAUTHCORE_EXPORT KAUTHCORE_DECL_DEPRECATED
#endif

#ifndef KAUTHCORE_DECL_DEPRECATED_NO_EXPORT
#  define KAUTHCORE_DECL_DEPRECATED_NO_EXPORT KAUTHCORE_NO_EXPORT KAUTHCORE_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KAUTHCORE_NO_DEPRECATED
#    define KAUTHCORE_NO_DEPRECATED
#  endif
#endif

#define KAUTHCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KAUTHCORE_NO_DEPRECATED) && !defined(KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KAUTHCORE_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KAUTHCORE_NO_DEPRECATED_WARNINGS) && !defined(KAUTHCORE_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KAUTHCORE_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KAUTHCORE_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KAUTHCORE_NO_DEPRECATED)
#  undef KAUTHCORE_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_NO_EXPORT
#elif defined(KAUTHCORE_NO_DEPRECATED_WARNINGS)
#  define KAUTHCORE_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_NO_EXPORT
#else
#  define KAUTHCORE_DEPRECATED KAUTHCORE_DECL_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_DECL_DEPRECATED_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KAUTHCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KAUTHCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KAUTHCORE_NO_DEPRECATED
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
#endif
#ifdef KAUTHCORE_NO_DEPRECATED_WARNINGS
#  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KAUTHCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x55500
#  endif
#endif

#ifndef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KAUTHCORE_DEPRECATED
#  define KAUTHCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KAUTHCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KAUTHCORE_DEPRECATED_WARNINGS_SINCE >= 0x54700
#  define KAUTHCORE_DEPRECATED_VERSION_5_71(text) KAUTHCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KAUTHCORE_DEPRECATED_VERSION_5_71(text)
#endif
#define KAUTHCORE_DEPRECATED_VERSION_5(minor, text)      KAUTHCORE_DEPRECATED_VERSION_5_##minor(text)
#define KAUTHCORE_DEPRECATED_VERSION(major, minor, text) KAUTHCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KAUTHCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KAUTHCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KAUTHCORE_DEPRECATED_VERSION(major, minor, text)
#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KAUTHCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KAUTHCORE_EXPORT_H */


#ifndef ECM_GENERATEEXPORTHEADER_KAUTHCORE_EXPORT_H
#define ECM_GENERATEEXPORTHEADER_KAUTHCORE_EXPORT_H


#define KAUTHCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KAUTHCORE_NO_DEPRECATED) && !defined(KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KAUTHCORE_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KAUTHCORE_NO_DEPRECATED_WARNINGS) && !defined(KAUTHCORE_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KAUTHCORE_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KAUTHCORE_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KAUTHCORE_NO_DEPRECATED)
#  undef KAUTHCORE_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_NO_EXPORT
#elif defined(KAUTHCORE_NO_DEPRECATED_WARNINGS)
#  define KAUTHCORE_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_NO_EXPORT
#else
#  define KAUTHCORE_DEPRECATED KAUTHCORE_DECL_DEPRECATED
#  define KAUTHCORE_DEPRECATED_EXPORT KAUTHCORE_DECL_DEPRECATED_EXPORT
#  define KAUTHCORE_DEPRECATED_NO_EXPORT KAUTHCORE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KAUTHCORE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KAUTHCORE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KAUTHCORE_NO_DEPRECATED
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
#endif
#ifdef KAUTHCORE_NO_DEPRECATED_WARNINGS
#  define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KAUTHCORE_DEPRECATED_WARNINGS_SINCE
#  ifdef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KAUTHCORE_DEPRECATED_WARNINGS_SINCE 0x55500
#  endif
#endif

#ifndef KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KAUTHCORE_DEPRECATED
#  define KAUTHCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KAUTHCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KAUTHCORE_DEPRECATED_WARNINGS_SINCE >= 0x54700
#  define KAUTHCORE_DEPRECATED_VERSION_5_71(text) KAUTHCORE_DECL_DEPRECATED_TEXT(text)
#else
#  define KAUTHCORE_DEPRECATED_VERSION_5_71(text)
#endif
#define KAUTHCORE_DEPRECATED_VERSION_5(minor, text)      KAUTHCORE_DEPRECATED_VERSION_5_##minor(text)
#define KAUTHCORE_DEPRECATED_VERSION(major, minor, text) KAUTHCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KAUTHCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KAUTHCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KAUTHCORE_DEPRECATED_VERSION(major, minor, text)
#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KAUTHCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KAUTHCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif


#endif /* ECM_GENERATEEXPORTHEADER_KAUTHCORE_EXPORT_H */
